@@ -77,7 +77,7 @@ def upload_main_image(request, obj, album_site, context):
             return HttpResponseRedirect(success_url) # Redirect after POST
         else:
             if request.is_ajax():
-                return HttpResponse(form.errors)
+                return HttpResponse(form.errors.as_text())
     else:
         form = album_site.upload_form_class()
 
@@ -108,7 +108,7 @@ def upload_zip(request, obj, album_site, context):
             return HttpResponseRedirect(success_url)
         else:
             if request.is_ajax():
-                return HttpResponse(form.errors)
+                return HttpResponse(form.errors.as_text())
     else:
         form = form_class(request.user, obj)
 
@@ -145,7 +145,7 @@ def upload_images(request, obj, album_site, context):
             return HttpResponseRedirect(success_url) # Redirect after POST
         else:
             if request.is_ajax():
-                return HttpResponse(formset.errors)
+                return HttpResponse(formset.errors.as_text())
     else:
         formset = FormsetCls(queryset = AttachedImage.objects.none())
 
